-- #######################################################################
--  Erstellung Tabellen Strukturen
-- #######################################################################

CREATE TABLE TBL_KUNDE(
  KUNDE_NR	NUMBER(10,0) NOT NULL ,
  VORNAME VARCHAR2(25) NOT NULL,	
  NACHNAME VARCHAR2(25) NOT NULL,
  STRASSE	 VARCHAR2(50),
  PLZ	 VARCHAR2(5),
  ORT	 VARCHAR2(20),
  GESCHLECHT VARCHAR2(1) CHECK(GESCHLECHT IN('M', 'm', 'F', 'f')),	
  GEBURTSTAG DATE DEFAULT TO_DATE('01.01.1900', 'DD.MM.YYYY'),
  CONSTRAINT PK_KUNDE PRIMARY KEY (KUNDE_NR)
);

CREATE TABLE TBL_MITARBEITER(
  MITARBEITER_NR NUMBER(10),
  VORNAME VARCHAR2(25),
  NACHNAME VARCHAR2(25),
  TYP VARCHAR2(15),
  GEHALT NUMBER(10,0),
  PROV_SATZ NUMBER(5,2),
  CONSTRAINT PK_MITARBEITER PRIMARY KEY (MITARBEITER_NR)
);


CREATE TABLE TBL_PRODUKTGRUPPE(
  PRODUKT_GRUPPE_NR   NUMBER(5,0) NOT NULL,
  BEZEICHNUNG   VARCHAR2(25),
  CONSTRAINT PK_PRODGRUPPE PRIMARY KEY (PRODUKT_GRUPPE_NR)
);


CREATE TABLE TBL_PRODUKT(
  PRODUKT_NR   NUMBER(5, 0) NOT NULL,
  BEZEICHNUNG   VARCHAR2(25),
  PREIS   NUMBER(10,2),
  PRODUKT_GRUPPE_NR   NUMBER(5, 0) NOT NULL,
  CONSTRAINT PK_PRODUKT PRIMARY KEY (PRODUKT_NR),
  CONSTRAINT FK_PROD_PROD_GRUPPE FOREIGN KEY (PRODUKT_GRUPPE_NR)
    REFERENCES TBL_PRODUKTGRUPPE(PRODUKT_GRUPPE_NR)
);

CREATE TABLE TBL_BESTELLUNG(
  BESTELLUNG_NR NUMBER(10,0) NOT NULL,	
  BESTELL_DATUM DATE NOT NULL,	
  ABHOLER_FLAG NUMBER(1,0) NOT NULL,	
  KUNDE_NR NUMBER(10,0) NOT NULL,	
  FAHRER_NR	NUMBER(10,0),
  VERKAEUFER_NR NUMBER(10,0),
  CONSTRAINT PK_BESTELLUNG PRIMARY KEY (BESTELLUNG_NR),
  CONSTRAINT FK_BESTELLUNG_KUNDE FOREIGN KEY (KUNDE_NR)
      REFERENCES TBL_KUNDE(KUNDE_NR),
  CONSTRAINT FK_BESTELLUNG_VERKAEUFER FOREIGN KEY (VERKAEUFER_NR)
      REFERENCES TBL_MITARBEITER(MITARBEITER_NR)	  
);

CREATE TABLE TBL_BESTELLUNG_POS(
  BESTELLUNG_NR NUMBER(10) NOT NULL,	
  PRODUKT_NR NUMBER(10) NOT NULL	,
  ANZAHL NUMBER(10) NOT NULL,
  CONSTRAINT PK_BESTELLUNG_POS PRIMARY KEY(BESTELLUNG_NR, PRODUKT_NR),
  CONSTRAINT FK_BEST_POS_BEST FOREIGN KEY(BESTELLUNG_NR)
    REFERENCES TBL_BESTELLUNG(BESTELLUNG_NR)
);

-- #######################################################################
--  Erstellung Testdaten
-- #######################################################################

INSERT INTO TBL_KUNDE VALUES(1, 'Horst', 'Huber', 'Karolinenweg 11a', '20357', 'Hamburg', 'M', to_date('01.05.1975', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(2, 'Erika', 'Schmidt', 'Goethestrae 5', '22512', 'Hamburg', 'F', to_date('05.10.1985', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(3, 'Bert', 'Mller', 'Schwedenweg 22', '22123', 'Hamburg', 'm', to_date('03.02.1979', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(4, 'Hubertus', 'Meyer-Huber', 'Hamburger Strae 67', '24106', 'Kiel', 'M', to_date('15.07.1958', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(5, 'Hanna', 'von Bergmann', 'Werftstrae 22', '24145', 'Kiel', 'f', to_date('17.09.1965', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(6, 'Tobias', 'Maier', 'Frdeweg 2', '26105', 'Flensburg', 'M', to_date('03.03.1992', 'DD.MM.YYYY'));
INSERT INTO TBL_KUNDE VALUES(7, 'Fabian', 'Lindemann', 'Kieler Strae 102', '23809', 'Lbeck', 'm', to_date('01.09.1973', 'DD.MM.YYYY'));

commit;

INSERT INTO TBL_PRODUKTGRUPPE VALUES(1, 'Fleischgerichte');
INSERT INTO TBL_PRODUKTGRUPPE VALUES(2, 'Pizzen');
INSERT INTO TBL_PRODUKTGRUPPE VALUES(3, 'Pasta');
INSERT INTO TBL_PRODUKTGRUPPE VALUES(4, 'Getrnke');
INSERT INTO TBL_PRODUKTGRUPPE VALUES(5, 'Desserts');
INSERT INTO TBL_PRODUKTGRUPPE VALUES(6, 'Sonstige');

commit;

INSERT INTO TBL_PRODUKT VALUES(1, 'Rumpsteak', 20.95, 1);
INSERT INTO TBL_PRODUKT VALUES(2, 'Grillteller', 14.95, 1);
INSERT INTO TBL_PRODUKT VALUES(3, 'Pizza Salami', 5.6, 2);
INSERT INTO TBL_PRODUKT VALUES(4, 'Pizza Hawai', 6.1, 2);
INSERT INTO TBL_PRODUKT VALUES(5, 'Pizza Thunfisch', 6.1, 2);
INSERT INTO TBL_PRODUKT VALUES(6, 'Pizza Spezial', 6.95, 2);
INSERT INTO TBL_PRODUKT VALUES(7, 'Pizza Vital', 5.8, 2);
INSERT INTO TBL_PRODUKT VALUES(8, 'Spagetti Bolognese', 4.5, 3);
INSERT INTO TBL_PRODUKT VALUES(9, 'Lasagne', 4.5, 3);
INSERT INTO TBL_PRODUKT VALUES(10, 'Tagliatelle Carbonara', 4.5, 3);
INSERT INTO TBL_PRODUKT VALUES(11, 'Cola 0,33l', 1.75, 4);
INSERT INTO TBL_PRODUKT VALUES(12, 'Bier Holsten 0,5l', 2, 4);
INSERT INTO TBL_PRODUKT VALUES(13, 'Wasser 1,5l Kohlensure', 2, 4);
INSERT INTO TBL_PRODUKT VALUES(14, 'Obstsalat', 3, 5);
INSERT INTO TBL_PRODUKT VALUES(15, 'Tiramisu', 4, 5);
INSERT INTO TBL_PRODUKT VALUES(16, 'Joghurt', null, 5);

commit;


INSERT INTO TBL_MITARBEITER VALUES(1, 'Liese', 'Mller', 'FAHRER', 1000, 0.01);
INSERT INTO TBL_MITARBEITER VALUES(2, 'Peter', 'Peters', 'FAHRER', 1000, 0.01);
INSERT INTO TBL_MITARBEITER VALUES(3, 'Horst', 'Schmidt', 'FAHRER', 1500, 0.01);
INSERT INTO TBL_MITARBEITER VALUES(4, 'Klaus', 'Klausen', 'FAHRER', 1200, 0.01);
INSERT INTO TBL_MITARBEITER VALUES(5, 'Steffi', 'Mller', 'FAHRER', 1000, 0.01);
INSERT INTO TBL_MITARBEITER VALUES(6, 'Emil', 'Iversen', 'VERKUFER', 1500, 0.10);
INSERT INTO TBL_MITARBEITER VALUES(7, 'Sandra', 'Meier', 'VERKUFER', 1750, 0.15);
INSERT INTO TBL_MITARBEITER VALUES(8, 'Sandra', 'Bergmann', 'VERKUFER', 1750, 0.07);
INSERT INTO TBL_MITARBEITER VALUES(9, 'Kevin', 'Knutsen', 'KOCH', 2000, 0.02);
INSERT INTO TBL_MITARBEITER VALUES(10, 'Thomas', 'Thomsen', 'KOCH', 2200, 0.02);
INSERT INTO TBL_MITARBEITER VALUES(11, 'Sabine', 'Maier', 'VERKUFER', 1000, 0.05);

commit;

INSERT INTO TBL_BESTELLUNG VALUES(1, to_date('01.01.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(2, to_date('03.02.2013', 'DD.MM.YYYY'),0, 6, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(3, to_date('17.11.2013', 'DD.MM.YYYY'),1, 7, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(4, to_date('07.08.2013', 'DD.MM.YYYY'),1, 3, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(5, to_date('03.09.2013', 'DD.MM.YYYY'),0, 5, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(6, to_date('24.08.2013', 'DD.MM.YYYY'),0, 5, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(7, to_date('27.06.2013', 'DD.MM.YYYY'),1, 7, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(8, to_date('08.02.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(9, to_date('12.07.2013', 'DD.MM.YYYY'),0, 2, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(10, to_date('05.03.2013', 'DD.MM.YYYY'),0, 2, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(11, to_date('18.02.2013', 'DD.MM.YYYY'),0, 1, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(12, to_date('08.07.2013', 'DD.MM.YYYY'),0, 5, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(13, to_date('07.11.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(14, to_date('22.02.2013', 'DD.MM.YYYY'),0, 5, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(15, to_date('10.09.2013', 'DD.MM.YYYY'),0, 2, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(16, to_date('26.05.2013', 'DD.MM.YYYY'),0, 3, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(17, to_date('17.08.2013', 'DD.MM.YYYY'),0, 5, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(18, to_date('18.01.2013', 'DD.MM.YYYY'),0, 6, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(19, to_date('28.07.2013', 'DD.MM.YYYY'),1, 7, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(20, to_date('05.09.2013', 'DD.MM.YYYY'),0, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(21, to_date('09.11.2013', 'DD.MM.YYYY'),1, 6, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(22, to_date('26.06.2013', 'DD.MM.YYYY'),0, 6, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(23, to_date('14.01.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(24, to_date('15.08.2013', 'DD.MM.YYYY'),0, 4, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(25, to_date('17.06.2013', 'DD.MM.YYYY'),0, 3, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(26, to_date('26.11.2013', 'DD.MM.YYYY'),0, 4, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(27, to_date('16.05.2013', 'DD.MM.YYYY'),0, 3, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(28, to_date('01.11.2013', 'DD.MM.YYYY'),0, 4, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(29, to_date('20.02.2013', 'DD.MM.YYYY'),1, 5, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(30, to_date('15.03.2013', 'DD.MM.YYYY'),0, 2, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(31, to_date('25.06.2013', 'DD.MM.YYYY'),0, 4, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(32, to_date('01.06.2013', 'DD.MM.YYYY'),0, 2, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(33, to_date('19.08.2013', 'DD.MM.YYYY'),1, 5, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(34, to_date('26.02.2013', 'DD.MM.YYYY'),1, 1, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(35, to_date('04.01.2013', 'DD.MM.YYYY'),0, 7, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(36, to_date('04.02.2013', 'DD.MM.YYYY'),0, 3, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(37, to_date('17.04.2013', 'DD.MM.YYYY'),0, 2, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(38, to_date('13.10.2013', 'DD.MM.YYYY'),0, 1, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(39, to_date('26.03.2013', 'DD.MM.YYYY'),0, 4, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(40, to_date('18.07.2013', 'DD.MM.YYYY'),0, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(41, to_date('10.11.2013', 'DD.MM.YYYY'),1, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(42, to_date('10.03.2013', 'DD.MM.YYYY'),0, 6, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(43, to_date('21.09.2013', 'DD.MM.YYYY'),1, 7, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(44, to_date('03.12.2013', 'DD.MM.YYYY'),0, 6, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(45, to_date('22.04.2013', 'DD.MM.YYYY'),1, 1, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(46, to_date('08.06.2013', 'DD.MM.YYYY'),0, 6, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(47, to_date('19.01.2013', 'DD.MM.YYYY'),0, 7, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(48, to_date('23.06.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(49, to_date('08.03.2013', 'DD.MM.YYYY'),0, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(50, to_date('09.08.2013', 'DD.MM.YYYY'),0, 6, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(51, to_date('22.08.2013', 'DD.MM.YYYY'),1, 5, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(52, to_date('10.08.2013', 'DD.MM.YYYY'),1, 1, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(53, to_date('05.01.2013', 'DD.MM.YYYY'),0, 7, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(54, to_date('18.06.2013', 'DD.MM.YYYY'),0, 3, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(55, to_date('17.04.2013', 'DD.MM.YYYY'),1, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(56, to_date('25.03.2013', 'DD.MM.YYYY'),0, 5, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(57, to_date('26.09.2013', 'DD.MM.YYYY'),1, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(58, to_date('21.07.2013', 'DD.MM.YYYY'),0, 6, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(59, to_date('03.01.2013', 'DD.MM.YYYY'),1, 6, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(60, to_date('08.03.2013', 'DD.MM.YYYY'),0, 3, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(61, to_date('28.04.2013', 'DD.MM.YYYY'),0, 7, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(62, to_date('10.11.2013', 'DD.MM.YYYY'),0, 1, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(63, to_date('07.03.2013', 'DD.MM.YYYY'),0, 6, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(64, to_date('14.02.2013', 'DD.MM.YYYY'),0, 5, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(65, to_date('06.12.2013', 'DD.MM.YYYY'),0, 2, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(66, to_date('03.08.2013', 'DD.MM.YYYY'),0, 7, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(67, to_date('02.01.2013', 'DD.MM.YYYY'),1, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(68, to_date('06.04.2013', 'DD.MM.YYYY'),0, 5, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(69, to_date('01.12.2013', 'DD.MM.YYYY'),0, 1, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(70, to_date('05.09.2013', 'DD.MM.YYYY'),1, 3, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(71, to_date('07.02.2013', 'DD.MM.YYYY'),0, 1, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(72, to_date('09.07.2013', 'DD.MM.YYYY'),0, 1, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(73, to_date('20.03.2013', 'DD.MM.YYYY'),0, 1, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(74, to_date('19.03.2013', 'DD.MM.YYYY'),0, 5, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(75, to_date('08.07.2013', 'DD.MM.YYYY'),0, 4, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(76, to_date('03.11.2013', 'DD.MM.YYYY'),0, 2, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(77, to_date('15.04.2013', 'DD.MM.YYYY'),1, 6, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(78, to_date('10.01.2013', 'DD.MM.YYYY'),0, 4, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(79, to_date('25.06.2013', 'DD.MM.YYYY'),0, 1, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(80, to_date('06.09.2013', 'DD.MM.YYYY'),0, 3, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(81, to_date('07.04.2013', 'DD.MM.YYYY'),0, 6, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(82, to_date('19.04.2013', 'DD.MM.YYYY'),0, 1, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(83, to_date('12.11.2013', 'DD.MM.YYYY'),0, 7, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(84, to_date('26.01.2013', 'DD.MM.YYYY'),1, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(85, to_date('04.03.2013', 'DD.MM.YYYY'),0, 6, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(86, to_date('14.01.2013', 'DD.MM.YYYY'),1, 4, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(87, to_date('15.05.2013', 'DD.MM.YYYY'),0, 5, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(88, to_date('03.08.2013', 'DD.MM.YYYY'),0, 4, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(89, to_date('21.03.2013', 'DD.MM.YYYY'),1, 6, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(90, to_date('28.07.2013', 'DD.MM.YYYY'),0, 6, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(91, to_date('10.10.2013', 'DD.MM.YYYY'),1, 5, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(92, to_date('22.01.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(93, to_date('15.12.2013', 'DD.MM.YYYY'),1, 3, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(94, to_date('10.07.2013', 'DD.MM.YYYY'),0, 5, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(95, to_date('18.08.2013', 'DD.MM.YYYY'),0, 5, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(96, to_date('09.04.2013', 'DD.MM.YYYY'),0, 2, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(97, to_date('02.04.2013', 'DD.MM.YYYY'),0, 3, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(98, to_date('20.10.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(99, to_date('10.05.2013', 'DD.MM.YYYY'),0, 6, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(100, to_date('07.07.2013', 'DD.MM.YYYY'),0, 2, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(101, to_date('03.10.2013', 'DD.MM.YYYY'),0, 7, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(102, to_date('15.05.2013', 'DD.MM.YYYY'),0, 4, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(103, to_date('21.11.2013', 'DD.MM.YYYY'),0, 1, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(104, to_date('26.01.2013', 'DD.MM.YYYY'),1, 5, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(105, to_date('14.10.2013', 'DD.MM.YYYY'),0, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(106, to_date('28.10.2013', 'DD.MM.YYYY'),0, 7, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(107, to_date('23.11.2013', 'DD.MM.YYYY'),0, 7, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(108, to_date('09.04.2013', 'DD.MM.YYYY'),0, 7, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(109, to_date('14.01.2013', 'DD.MM.YYYY'),1, 6, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(110, to_date('05.11.2013', 'DD.MM.YYYY'),1, 6, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(111, to_date('22.03.2013', 'DD.MM.YYYY'),1, 5, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(112, to_date('01.09.2013', 'DD.MM.YYYY'),1, 1, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(113, to_date('21.08.2013', 'DD.MM.YYYY'),0, 3, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(114, to_date('11.03.2013', 'DD.MM.YYYY'),0, 2, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(115, to_date('03.07.2013', 'DD.MM.YYYY'),1, 3, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(116, to_date('22.11.2013', 'DD.MM.YYYY'),0, 5, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(117, to_date('12.10.2013', 'DD.MM.YYYY'),0, 6, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(118, to_date('17.05.2013', 'DD.MM.YYYY'),0, 4, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(119, to_date('18.09.2013', 'DD.MM.YYYY'),0, 5, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(120, to_date('05.03.2013', 'DD.MM.YYYY'),0, 2, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(121, to_date('18.01.2013', 'DD.MM.YYYY'),1, 1, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(122, to_date('19.08.2013', 'DD.MM.YYYY'),0, 3, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(123, to_date('05.11.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(124, to_date('17.12.2013', 'DD.MM.YYYY'),0, 2, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(125, to_date('27.02.2013', 'DD.MM.YYYY'),1, 4, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(126, to_date('16.11.2013', 'DD.MM.YYYY'),0, 1, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(127, to_date('14.12.2013', 'DD.MM.YYYY'),0, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(128, to_date('07.11.2013', 'DD.MM.YYYY'),0, 6, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(129, to_date('20.11.2013', 'DD.MM.YYYY'),1, 4, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(130, to_date('21.03.2013', 'DD.MM.YYYY'),0, 5, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(131, to_date('14.10.2013', 'DD.MM.YYYY'),0, 4, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(132, to_date('03.05.2013', 'DD.MM.YYYY'),0, 6, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(133, to_date('01.04.2013', 'DD.MM.YYYY'),0, 4, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(134, to_date('10.12.2013', 'DD.MM.YYYY'),1, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(135, to_date('14.01.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(136, to_date('25.04.2013', 'DD.MM.YYYY'),1, 7, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(137, to_date('20.03.2013', 'DD.MM.YYYY'),0, 6, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(138, to_date('03.01.2013', 'DD.MM.YYYY'),0, 1, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(139, to_date('03.08.2013', 'DD.MM.YYYY'),0, 6, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(140, to_date('04.11.2013', 'DD.MM.YYYY'),0, 4, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(141, to_date('05.03.2013', 'DD.MM.YYYY'),0, 5, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(142, to_date('01.06.2013', 'DD.MM.YYYY'),0, 1, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(143, to_date('25.08.2013', 'DD.MM.YYYY'),0, 6, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(144, to_date('10.04.2013', 'DD.MM.YYYY'),0, 3, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(145, to_date('16.10.2013', 'DD.MM.YYYY'),0, 7, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(146, to_date('21.11.2013', 'DD.MM.YYYY'),0, 4, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(147, to_date('16.10.2013', 'DD.MM.YYYY'),0, 3, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(148, to_date('16.02.2013', 'DD.MM.YYYY'),0, 5, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(149, to_date('24.02.2013', 'DD.MM.YYYY'),1, 1, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(150, to_date('02.10.2013', 'DD.MM.YYYY'),0, 5, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(151, to_date('07.02.2013', 'DD.MM.YYYY'),0, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(152, to_date('18.07.2013', 'DD.MM.YYYY'),1, 3, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(153, to_date('05.12.2013', 'DD.MM.YYYY'),1, 2, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(154, to_date('06.03.2013', 'DD.MM.YYYY'),0, 2, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(155, to_date('22.03.2013', 'DD.MM.YYYY'),0, 7, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(156, to_date('02.04.2013', 'DD.MM.YYYY'),0, 3, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(157, to_date('14.02.2013', 'DD.MM.YYYY'),0, 4, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(158, to_date('16.05.2013', 'DD.MM.YYYY'),1, 2, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(159, to_date('20.12.2013', 'DD.MM.YYYY'),1, 4, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(160, to_date('06.12.2013', 'DD.MM.YYYY'),0, 7, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(161, to_date('19.05.2013', 'DD.MM.YYYY'),0, 2, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(162, to_date('01.05.2013', 'DD.MM.YYYY'),0, 1, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(163, to_date('01.12.2013', 'DD.MM.YYYY'),0, 6, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(164, to_date('02.02.2013', 'DD.MM.YYYY'),0, 3, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(165, to_date('03.07.2013', 'DD.MM.YYYY'),0, 4, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(166, to_date('27.09.2013', 'DD.MM.YYYY'),0, 1, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(167, to_date('12.10.2013', 'DD.MM.YYYY'),1, 1, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(168, to_date('04.04.2013', 'DD.MM.YYYY'),0, 3, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(169, to_date('10.10.2013', 'DD.MM.YYYY'),0, 7, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(170, to_date('20.04.2013', 'DD.MM.YYYY'),0, 4, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(171, to_date('04.02.2013', 'DD.MM.YYYY'),1, 3, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(172, to_date('21.01.2013', 'DD.MM.YYYY'),0, 6, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(173, to_date('15.01.2013', 'DD.MM.YYYY'),1, 6, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(174, to_date('01.06.2013', 'DD.MM.YYYY'),0, 6, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(175, to_date('18.05.2013', 'DD.MM.YYYY'),0, 3, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(176, to_date('19.10.2013', 'DD.MM.YYYY'),0, 5, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(177, to_date('26.09.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(178, to_date('20.07.2013', 'DD.MM.YYYY'),0, 5, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(179, to_date('12.01.2013', 'DD.MM.YYYY'),0, 4, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(180, to_date('07.04.2013', 'DD.MM.YYYY'),1, 3, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(181, to_date('16.03.2013', 'DD.MM.YYYY'),0, 2, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(182, to_date('17.02.2013', 'DD.MM.YYYY'),1, 7, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(183, to_date('08.08.2013', 'DD.MM.YYYY'),0, 6, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(184, to_date('12.05.2013', 'DD.MM.YYYY'),0, 1, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(185, to_date('13.12.2013', 'DD.MM.YYYY'),0, 3, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(186, to_date('21.11.2013', 'DD.MM.YYYY'),0, 5, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(187, to_date('27.12.2013', 'DD.MM.YYYY'),0, 5, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(188, to_date('19.11.2013', 'DD.MM.YYYY'),0, 2, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(189, to_date('10.12.2013', 'DD.MM.YYYY'),1, 6, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(190, to_date('23.05.2013', 'DD.MM.YYYY'),1, 6, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(191, to_date('21.09.2013', 'DD.MM.YYYY'),1, 5, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(192, to_date('19.11.2013', 'DD.MM.YYYY'),0, 5, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(193, to_date('01.05.2013', 'DD.MM.YYYY'),0, 6, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(194, to_date('17.09.2013', 'DD.MM.YYYY'),0, 1, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(195, to_date('27.11.2013', 'DD.MM.YYYY'),1, 3, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(196, to_date('05.08.2013', 'DD.MM.YYYY'),0, 1, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(197, to_date('28.02.2013', 'DD.MM.YYYY'),0, 7, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(198, to_date('10.12.2013', 'DD.MM.YYYY'),1, 5, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(199, to_date('26.07.2013', 'DD.MM.YYYY'),0, 4, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(200, to_date('21.11.2013', 'DD.MM.YYYY'),1, 2, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(201, to_date('08.11.2013', 'DD.MM.YYYY'),0, 4, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(202, to_date('14.04.2013', 'DD.MM.YYYY'),0, 1, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(203, to_date('07.04.2013', 'DD.MM.YYYY'),0, 2, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(204, to_date('13.01.2013', 'DD.MM.YYYY'),1, 2, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(205, to_date('17.11.2013', 'DD.MM.YYYY'),0, 5, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(206, to_date('24.03.2013', 'DD.MM.YYYY'),0, 6, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(207, to_date('07.05.2013', 'DD.MM.YYYY'),0, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(208, to_date('18.08.2013', 'DD.MM.YYYY'),1, 1, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(209, to_date('22.10.2013', 'DD.MM.YYYY'),0, 7, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(210, to_date('21.05.2013', 'DD.MM.YYYY'),0, 3, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(211, to_date('26.09.2013', 'DD.MM.YYYY'),0, 7, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(212, to_date('16.06.2013', 'DD.MM.YYYY'),1, 7, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(213, to_date('26.07.2013', 'DD.MM.YYYY'),1, 6, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(214, to_date('22.05.2013', 'DD.MM.YYYY'),0, 2, 1, 8);
INSERT INTO TBL_BESTELLUNG VALUES(215, to_date('17.03.2013', 'DD.MM.YYYY'),0, 5, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(216, to_date('10.11.2013', 'DD.MM.YYYY'),0, 4, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(217, to_date('11.03.2013', 'DD.MM.YYYY'),0, 5, 2, 8);
INSERT INTO TBL_BESTELLUNG VALUES(218, to_date('24.03.2013', 'DD.MM.YYYY'),0, 4, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(219, to_date('25.08.2013', 'DD.MM.YYYY'),0, 5, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(220, to_date('17.08.2013', 'DD.MM.YYYY'),0, 5, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(221, to_date('02.05.2013', 'DD.MM.YYYY'),0, 2, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(222, to_date('08.02.2013', 'DD.MM.YYYY'),1, 1, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(223, to_date('23.09.2013', 'DD.MM.YYYY'),0, 5, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(224, to_date('09.11.2013', 'DD.MM.YYYY'),1, 3, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(225, to_date('22.06.2013', 'DD.MM.YYYY'),1, 2, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(226, to_date('20.11.2013', 'DD.MM.YYYY'),1, 1, 3, 8);
INSERT INTO TBL_BESTELLUNG VALUES(227, to_date('09.06.2013', 'DD.MM.YYYY'),0, 1, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(228, to_date('06.01.2013', 'DD.MM.YYYY'),0, 7, 4, 7);
INSERT INTO TBL_BESTELLUNG VALUES(229, to_date('06.07.2013', 'DD.MM.YYYY'),0, 2, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(230, to_date('20.01.2013', 'DD.MM.YYYY'),0, 4, 4, 8);
INSERT INTO TBL_BESTELLUNG VALUES(231, to_date('01.10.2013', 'DD.MM.YYYY'),1, 3, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(232, to_date('08.03.2013', 'DD.MM.YYYY'),0, 7, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(233, to_date('11.08.2013', 'DD.MM.YYYY'),0, 1, 5, 7);
INSERT INTO TBL_BESTELLUNG VALUES(234, to_date('04.04.2013', 'DD.MM.YYYY'),1, 1, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(235, to_date('14.07.2013', 'DD.MM.YYYY'),0, 3, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(236, to_date('20.12.2013', 'DD.MM.YYYY'),0, 6, 1, 7);
INSERT INTO TBL_BESTELLUNG VALUES(237, to_date('21.10.2013', 'DD.MM.YYYY'),0, 3, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(238, to_date('21.03.2013', 'DD.MM.YYYY'),0, 4, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(239, to_date('20.10.2013', 'DD.MM.YYYY'),0, 6, 4, 6);
INSERT INTO TBL_BESTELLUNG VALUES(240, to_date('26.05.2013', 'DD.MM.YYYY'),0, 1, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(241, to_date('25.08.2013', 'DD.MM.YYYY'),1, 6, 5, 6);
INSERT INTO TBL_BESTELLUNG VALUES(242, to_date('07.06.2013', 'DD.MM.YYYY'),1, 4, 3, 7);
INSERT INTO TBL_BESTELLUNG VALUES(243, to_date('22.03.2013', 'DD.MM.YYYY'),0, 5, 2, 6);
INSERT INTO TBL_BESTELLUNG VALUES(244, to_date('27.10.2013', 'DD.MM.YYYY'),0, 3, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(245, to_date('28.02.2013', 'DD.MM.YYYY'),0, 4, 3, 6);
INSERT INTO TBL_BESTELLUNG VALUES(246, to_date('27.11.2013', 'DD.MM.YYYY'),0, 6, 2, 7);
INSERT INTO TBL_BESTELLUNG VALUES(247, to_date('07.03.2013', 'DD.MM.YYYY'),0, 3, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(248, to_date('08.07.2013', 'DD.MM.YYYY'),0, 4, 5, 8);
INSERT INTO TBL_BESTELLUNG VALUES(249, to_date('18.01.2013', 'DD.MM.YYYY'),1, 5, 1, 6);
INSERT INTO TBL_BESTELLUNG VALUES(250, to_date('01.04.2013', 'DD.MM.YYYY'),0, 4, 4, 7);

commit;

INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(1, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(2, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(2, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(3, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(4, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(5, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(5, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(5, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(6, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(6, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(6, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(7, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(8, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(8, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(8, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(8, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(8, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(9, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(10, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(11, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(12, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(12, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(13, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(13, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(13, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(13, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(13, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(14, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(14, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(15, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(16, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(16, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(16, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(16, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(16, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(17, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(17, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(17, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(17, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(18, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(18, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(19, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(20, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(20, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(20, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(20, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(20, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(21, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(21, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(21, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(22, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(22, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(23, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(24, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(24, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(24, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(24, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(24, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(25, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(26, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(26, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(26, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(26, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(27, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(28, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(29, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(29, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(29, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(30, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(31, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(31, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(31, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(31, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(32, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(32, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(32, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(32, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(32, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(33, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(33, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(33, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(34, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(35, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(36, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(36, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(36, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(36, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(37, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(38, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(38, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(38, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(38, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(38, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(39, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(39, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(39, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(39, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(40, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(40, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(40, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(40, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(40, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(41, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(41, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(41, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(42, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(42, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(43, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(44, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(44, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(45, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(46, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(47, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(48, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(49, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(49, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(50, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(51, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(51, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(51, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(51, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(52, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(53, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(53, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(53, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(53, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(53, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(54, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(54, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(54, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(54, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(55, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(55, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(55, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(56, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(56, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(57, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(58, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(58, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(59, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(60, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(61, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(62, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(63, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(64, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(64, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(65, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(65, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(65, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(65, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(65, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(66, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(67, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(67, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(67, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(67, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(67, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(68, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(68, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(68, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(69, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(69, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(69, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(69, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(69, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(70, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(70, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(70, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(70, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(71, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(71, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(71, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(71, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(71, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(72, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(73, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(74, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(74, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(75, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(75, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(75, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(75, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(76, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(77, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(78, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(78, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(78, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(79, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(80, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(80, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(80, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(80, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(80, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(81, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(82, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(83, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(84, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(84, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(85, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(86, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(86, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(86, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(87, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(87, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(87, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(88, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(88, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(88, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(88, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(89, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(90, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(91, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(91, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(92, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(93, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(93, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(93, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(93, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(93, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(94, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(94, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(94, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(95, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(95, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(95, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(96, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(97, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(98, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(99, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(99, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(100, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(100, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(100, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(100, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(100, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(101, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(102, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(102, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(102, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(102, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(103, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(104, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(104, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(104, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(105, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(105, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(106, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(107, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(108, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(109, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(110, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(110, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(111, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(111, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(111, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(111, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(112, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(113, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(113, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(113, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(113, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(114, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(115, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(116, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(116, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(116, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(117, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(118, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(118, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(118, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(118, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(119, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(119, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(119, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(120, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(121, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(122, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(122, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(122, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(122, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(122, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(123, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(124, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(125, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(125, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(125, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(125, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(126, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(127, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(127, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(127, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(128, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(128, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(129, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(129, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(129, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(129, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(130, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(130, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(130, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(131, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(131, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(131, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(132, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(133, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(133, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(133, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(133, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(134, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(135, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(136, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(137, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(138, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(138, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(138, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(138, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(138, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(139, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(140, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(140, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(140, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(140, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(141, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(141, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(142, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(143, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(144, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(144, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(144, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(144, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(145, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(146, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(146, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(146, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(146, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(147, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(147, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(147, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(147, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(148, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(148, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(149, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(149, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(149, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(149, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(149, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(150, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(150, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(151, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(151, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(151, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(151, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(152, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(152, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(152, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(152, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(152, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(153, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(154, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(154, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(154, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(154, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(155, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(156, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(156, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(156, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(156, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(156, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(157, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(157, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(157, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(157, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(158, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(158, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(158, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(158, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(159, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(159, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(159, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(160, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(161, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(161, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(161, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(161, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(162, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(163, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(164, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(164, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(164, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(164, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(165, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(165, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(166, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(166, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(166, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(166, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(166, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(167, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(168, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(168, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(168, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(169, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(170, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(170, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(170, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(171, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(171, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(171, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(171, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(171, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(172, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(173, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(174, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(175, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(175, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(175, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(175, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(176, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(176, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 9, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(177, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(178, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(178, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(178, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(179, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(179, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(179, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(180, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(180, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(180, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(180, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(180, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(181, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(181, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(181, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(181, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(182, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(183, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(184, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(184, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(184, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(184, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(184, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(185, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(185, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(185, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(185, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(186, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(186, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(187, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(187, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(188, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(189, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(190, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(191, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(191, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(192, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(192, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(193, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 1, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(194, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(195, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(195, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(195, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(195, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(195, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 5, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(196, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(197, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(198, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(198, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(199, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(199, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(199, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(199, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(200, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(201, 1, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(201, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(201, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(201, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(202, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(202, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(202, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(202, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(202, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(203, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(203, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(203, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(203, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 8, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(204, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(205, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(206, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(207, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(207, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(208, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(208, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(208, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(208, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 2, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(209, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(210, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(210, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(210, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(210, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(210, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 9, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 13, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(211, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 1, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 8, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 10, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(212, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 3, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 4, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(213, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(214, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(214, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(214, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(214, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(214, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(215, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(215, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(216, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(216, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(216, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(217, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(217, 15, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(218, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(218, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(218, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(218, 13, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(219, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(219, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(220, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(221, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(221, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(221, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(221, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(222, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(222, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(222, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(222, 11, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(222, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(223, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(224, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(224, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(224, 14, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(224, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(225, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(225, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(225, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(225, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(225, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(226, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(226, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(226, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(226, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(226, 14, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 9, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(227, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(228, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(228, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(228, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(228, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(228, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 8, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(229, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(230, 4, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(230, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(231, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(231, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(231, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 3, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 4, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 6, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(232, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 4, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 10, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(233, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 7, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 10, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(234, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(235, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(235, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(235, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(235, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 3, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 5, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 7, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 11, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 12, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(236, 15, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(237, 5, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(237, 10, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(237, 13, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(237, 15, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(238, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(238, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(238, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 1, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 5, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 6, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 7, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 13, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(239, 14, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 2, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 12, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(240, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 5, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 7, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 11, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 12, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(241, 15, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(242, 7, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(242, 8, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(243, 14, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(244, 2, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(244, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(244, 11, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(244, 12, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(245, 6, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(245, 12, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 2, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 6, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 8, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 9, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 11, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 13, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(246, 15, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(247, 3, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(247, 6, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(247, 10, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(247, 14, 1);
INSERT INTO TBL_BESTELLUNG_POS VALUES(248, 4, 4);
INSERT INTO TBL_BESTELLUNG_POS VALUES(248, 9, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(249, 2, 5);
INSERT INTO TBL_BESTELLUNG_POS VALUES(250, 1, 3);
INSERT INTO TBL_BESTELLUNG_POS VALUES(250, 3, 2);
INSERT INTO TBL_BESTELLUNG_POS VALUES(250, 13, 5);

commit;

