-- #####################################################################
--  KAP3: Demo 1 - Berechnung Summen Prod, ProdGruppe, Gesamt - klassisch
-- #####################################################################

SELECT  null AS PRDGRP_BEZ,
        null AS PRODUKT_BEZ, 
        SUM(bp.ANZAHL*p.PREIS) AS UMSATZ
FROM  TBL_BESTELLUNG_POS bp
  JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR

UNION ALL

SELECT  pg.PRODUKT_GRUPPE_NR||' - '||pg.BEZEICHNUNG AS PRDGRP_BEZ, 
        null AS PRODUKT_BEZ,
        SUM(bp.ANZAHL*p.PREIS)
FROM  TBL_BESTELLUNG_POS bp
  JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
  JOIN TBL_PRODUKTGRUPPE pg ON p.PRODUKT_GRUPPE_NR=pg.PRODUKT_GRUPPE_NR  
GROUP BY pg.BEZEICHNUNG, pg.PRODUKT_GRUPPE_NR

UNION ALL

SELECT  pg.PRODUKT_GRUPPE_NR||' - '||pg.BEZEICHNUNG AS PRDGRP_BEZ, 
        p.PRODUKT_NR||' - '||p.BEZEICHNUNG AS PRODUKT_BEZ, 
        SUM(bp.ANZAHL*p.PREIS)
FROM  TBL_BESTELLUNG_POS bp
  JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
  JOIN TBL_PRODUKTGRUPPE pg ON p.PRODUKT_GRUPPE_NR=pg.PRODUKT_GRUPPE_NR    
GROUP BY p.PRODUKT_NR, p.BEZEICHNUNG, pg.PRODUKT_GRUPPE_NR, pg.BEZEICHNUNG

ORDER BY 1 NULLS FIRST, 2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 2  - Berechnung Summen Prod, ProdGruppe, Gesamt - ROLLUP
-- #####################################################################

SELECT  pg.PRODUKT_GRUPPE_NR||' - '||pg.BEZEICHNUNG AS PRDGRP_BEZ,
               p.PRODUKT_NR||' - '||p.BEZEICHNUNG AS PRODUKT_BEZ,
              SUM(bp.ANZAHL*p.PREIS) AS UMSATZ
FROM TBL_BESTELLUNG_POS bp
    JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
    JOIN TBL_PRODUKTGRUPPE pg ON p.PRODUKT_GRUPPE_NR=pg.PRODUKT_GRUPPE_NR
GROUP BY ROLLUP ( pg.PRODUKT_GRUPPE_NR||' - '||pg.BEZEICHNUNG,
                                        p.PRODUKT_NR||' - '||p.BEZEICHNUNG )
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;


-- #####################################################################
--  KAP3: Demo 3 - 
-- #####################################################################

SELECT  pg.PRODUKT_GRUPPE_NR||' - '||pg.BEZEICHNUNG AS PRDGRP_BEZ,
               p.PRODUKT_NR||' - '||p.BEZEICHNUNG AS PRODUKT_BEZ,
              SUM(bp.ANZAHL*p.PREIS) AS UMSATZ
FROM TBL_BESTELLUNG_POS bp
    JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
    JOIN TBL_PRODUKTGRUPPE pg ON p.PRODUKT_GRUPPE_NR=pg.PRODUKT_GRUPPE_NR
GROUP BY ROLLUP ( (pg.PRODUKT_GRUPPE_NR, pg.BEZEICHNUNG),
                                       ( p.PRODUKT_NR, p.BEZEICHNUNG) )
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 4 - Composite Columns
-- #####################################################################

SELECT  to_char(b.BESTELL_DATUM,'YYYYMM') AS MONAT,
        p.PRODUKT_NR,
        p.BEZEICHNUNG AS PRODUKT_BEZ,
        SUM(bp.ANZAHL*p.PREIS) AS UMSATZ
FROM TBL_BESTELLUNG b
   JOIN TBL_BESTELLUNG_POS bp ON b.BESTELLuNG_NR=bp.BESTELLUNG_NR
   JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
WHERE p.PRODUKT_NR IN(1,2)
AND to_char(b.BESTELL_DATUM,'YYYYMM') IN('201301', '201302')
GROUP BY ROLLUP(to_char(b.BESTELL_DATUM,'YYYYMM'), (p.PRODUKT_NR, p.BEZEICHNUNG))
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 5 - Beispiel CUBE
-- #####################################################################

SELECT  to_char(b.BESTELL_DATUM,'YYYYMM') AS MONAT,
        p.PRODUKT_NR,
        p.BEZEICHNUNG AS PRODUKT_BEZ,
        SUM(bp.ANZAHL*p.PREIS) AS UMSATZ
FROM TBL_BESTELLUNG b
   JOIN TBL_BESTELLUNG_POS bp ON b.BESTELLuNG_NR=bp.BESTELLUNG_NR
   JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
WHERE p.PRODUKT_NR IN(1,2)
AND to_char(b.BESTELL_DATUM,'YYYYMM') IN('201301', '201302')
GROUP BY CUBE(to_char(b.BESTELL_DATUM,'YYYYMM'), (p.PRODUKT_NR, p.BEZEICHNUNG))
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 6 - Beispiel GROUPING()
-- #####################################################################

SELECT  to_char(b.BESTELL_DATUM,'YYYYMM') AS MONAT,
        p.PRODUKT_NR,
        p.BEZEICHNUNG AS PRODUKT_BEZ,
        SUM(bp.ANZAHL*p.PREIS) AS UMSATZ,
        GROUPING(to_char(b.BESTELL_DATUM,'YYYYMM') ) AS GRP_MON,
        GROUPING(p.PRODUKT_NR) AS GRP_PRD
FROM TBL_BESTELLUNG b
   JOIN TBL_BESTELLUNG_POS bp ON b.BESTELLuNG_NR=bp.BESTELLUNG_NR
   JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
WHERE p.PRODUKT_NR IN(1,2)
AND to_char(b.BESTELL_DATUM,'YYYYMM') IN('201301', '201302')
GROUP BY ROLLUP(to_char(b.BESTELL_DATUM,'YYYYMM'), (p.PRODUKT_NR, p.BEZEICHNUNG))
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 7 - Beispiel GROUPING_ID()
-- #####################################################################

SELECT  to_char(b.BESTELL_DATUM,'YYYYMM') AS MONAT,
        p.PRODUKT_NR,
        p.BEZEICHNUNG AS PRODUKT_BEZ,
        SUM(bp.ANZAHL*p.PREIS) AS UMSATZ,
        GROUPING_ID(to_char(b.BESTELL_DATUM,'YYYYMM'),p.PRODUKT_NR) AS GRP
FROM TBL_BESTELLUNG b
   JOIN TBL_BESTELLUNG_POS bp ON b.BESTELLuNG_NR=bp.BESTELLUNG_NR
   JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR
WHERE p.PRODUKT_NR IN(1,2)
AND to_char(b.BESTELL_DATUM,'YYYYMM') IN('201301', '201302')
GROUP BY ROLLUP(to_char(b.BESTELL_DATUM,'YYYYMM'), (p.PRODUKT_NR, p.BEZEICHNUNG))
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;

-- #####################################################################
--  KAP3: Demo 8 - Beispiel GROUPING SETS
-- #####################################################################
SELECT to_char(b.BESTELL_DATUM,'YYYYMM') AS MONAT, 
       p.PRODUKT_NR, p.BEZEICHNUNG AS PRODUKT_BEZ, 
       pg.PRODUKT_GRUPPE_NR, pg.BEZEICHNUNG AS PRDGRP_BEZ, 
       SUM(bp.ANZAHL*p.PREIS) AS UMSATZ 
FROM TBL_BESTELLUNG b 
  JOIN TBL_BESTELLUNG_POS bp ON b.BESTELLuNG_NR=bp.BESTELLUNG_NR 
  JOIN TBL_PRODUKT p ON bp.PRODUKT_NR=p.PRODUKT_NR 
  JOIN TBL_PRODUKTGRUPPE pg ON p.PRODUKT_GRUPPE_NR=pg.PRODUKT_GRUPPE_NR 
WHERE p.PRODUKT_NR IN(1,2,3) 
AND to_char(b.BESTELL_DATUM,'YYYYMM') IN('201301', '201302') 
GROUP BY GROUPING SETS ( to_char(b.BESTELL_DATUM,'YYYYMM'), 
                       (to_char(b.BESTELL_DATUM,'YYYYMM'), p.PRODUKT_NR, p.BEZEICHNUNG), 
                       (pg.PRODUKT_GRUPPE_NR, pg.BEZEICHNUNG), () ) 
ORDER BY 1 NULLS FIRST,2 NULLS FIRST;